==> removebg_infusiblecoder-0.0.1.tar.gz: removebg_infusiblecoder-0.0.1/setup.py <==
import os
import pathlib
import sys

sys.path.append(os.path.dirname(__file__))
from setuptools import find_packages, setup

import versioneer

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / "README.md").read_text(encoding="utf-8")

with open(here / "requirements.txt") as f:
    requireds = f.read().splitlines()

with open(here / "requirements-gpu.txt") as f:
    gpu_requireds = f.read().splitlines()

setup(
    name="removebg_infusiblecoder",
    description="Remove image background",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/syedusama5556/removebg_infusiblecoder",
    author="Syed Usama Ahmad",
    author_email="syedusama5556@gmail.com",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    keywords="remove, background, u2net",
    packages=["removebg_infusiblecoder"],
    python_requires=">3.7, <3.11",
    install_requires=requireds,
    entry_points={
        "console_scripts": [
            "removebg_infusiblecoder=removebg_infusiblecoder.cli:main",
        ],
    },
    extras_require={
        "gpu": gpu_requireds,
    },
    version='0.0.1',
   
)

==> removebg_infusiblecoder-0.0.2.tar.gz: removebg_infusiblecoder-0.0.2/setup.py <==
import versioneer
from setuptools import find_packages, setup
import os
import pathlib
import sys

sys.path.append(os.path.dirname(__file__))


here = pathlib.Path(__file__).parent.resolve()

long_description = (here / "README.md").read_text(encoding="utf-8")


setup(
    name="removebg_infusiblecoder",
    description="Remove image background",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/syedusama5556/removebg_infusiblecoder",
    author="Syed Usama Ahmad",
    author_email="syedusama5556@gmail.com",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Mathematics",
        "Topic :: Scientific/Engineering :: Artificial Intelligence",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    keywords="remove, background, u2net",
    packages=["removebg_infusiblecoder"],
    python_requires=">3.7, <3.11",
    install_requires=[
        "aiohttp~=3.8.1",
        "asyncer~=0.0.2",
        "click~=8.1.3",
        "fastapi~=0.87.0",
        "filetype~=1.2.0",
        "pooch~=1.6.0",
        "imagehash~=4.3.1",
        "numpy~=1.23.5",
        "onnxruntime~=1.13.1",
        "opencv-python-headless~=4.6.0.66",
        "pillow~=9.3.0",
        "pymatting~=1.1.8",
        "python-multipart~=0.0.5",
        "scikit-image~=0.19.3",
        "scipy~=1.9.3",
        "tqdm~=4.64.1",
        "uvicorn~=0.20.0",
        "watchdog~=2.1.9",
    ],
    entry_points={
        "console_scripts": [
            "removebg_infusiblecoder=removebg_infusiblecoder.cli:main",
        ],
    },
    extras_require={
        "gpu": ["onnxruntime-gpu~=1.13.1"],
    },
    version='0.0.2',

)
